==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/bmp/skin_caption.gif.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_caption.gif"

unsigned char _mgir_gif_skin_caption_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x42,0x00,	0x40,0x00,0xE6,0x00,0x00,0xB9,0xB9,0xB9,
	0xAA,0xAA,0xAA,0x7E,0x7E,0x7E,0x7D,0x7D,	0x7D,0x7B,0x7B,0x7B,0x7A,0x7A,0x7A,0x79,
	0x79,0x79,0x78,0x78,0x78,0x76,0x76,0x76,	0x74,0x74,0x74,0x73,0x73,0x73,0x71,0x71,
	0x71,0x70,0x70,0x70,0x6E,0x6E,0x6E,0x6C,	0x6C,0x6C,0x6A,0x6A,0x6A,0x67,0x67,0x67,
	0x66,0x66,0x66,0x65,0x65,0x65,0x62,0x62,	0x62,0x61,0x61,0x61,0x5F,0x5F,0x5F,0x5E,
	0x5E,0x5E,0x5D,0x5D,0x5D,0x5C,0x5C,0x5C,	0x5B,0x5B,0x5B,0x59,0x59,0x59,0x56,0x56,
	0x56,0x55,0x55,0x55,0x52,0x52,0x52,0x51,	0x51,0x51,0x4F,0x4F,0x4F,0x4D,0x4D,0x4D,
	0x4C,0x4C,0x4C,0x4B,0x4B,0x4B,0x4A,0x4A,	0x4A,0x49,0x49,0x49,0x47,0x47,0x47,0x46,
	0x46,0x46,0x45,0x45,0x45,0x44,0x44,0x44,	0x42,0x42,0x42,0x40,0x40,0x40,0x3E,0x3E,
	0x3E,0x3D,0x3D,0x3D,0x3C,0x3C,0x3C,0x3B,	0x3B,0x3B,0x3A,0x3A,0x3A,0x39,0x39,0x39,
	0x36,0x36,0x36,0x24,0x24,0x24,0x22,0x22,	0x22,0x20,0x20,0x20,0x1E,0x1E,0x1E,0x1C,
	0x1C,0x1C,0x1A,0x1A,0x1A,0x19,0x19,0x19,	0x17,0x17,0x17,0x15,0x15,0x15,0x14,0x14,
	0x14,0x12,0x12,0x12,0x11,0x11,0x11,0x10,	0x10,0x10,0x0F,0x0F,0x0F,0x0E,0x0E,0x0E,
	0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x21,0xF9,0x04,
	0x01,0x00,0x00,0x41,0x00,0x2C,0x00,0x00,	0x00,0x00,0x42,0x00,0x40,0x00,0x00,0x07,
	0xFF,0x80,0x13,0x82,0x83,0x13,0x14,0x86,	0x87,0x88,0x89,0x8A,0x83,0x88,0x84,0x8E,
	0x8E,0x8A,0x14,0x8F,0x84,0x91,0x95,0x96,	0x97,0x98,0x99,0x96,0x15,0x9C,0x9D,0x9E,
	0x9F,0xA0,0x16,0xA2,0x16,0xA0,0xA5,0xA6,	0xA7,0xA8,0x15,0x17,0xAB,0xAC,0xAD,0xAE,
	0xAF,0xB0,0xB1,0xB2,0xB3,0xB4,0x19,0xB6,	0xB7,0xB8,0xB9,0xBA,0xBB,0xBC,0xBD,0xBE,
	0xBF,0x1A,0xC1,0xC2,0xC3,0xC4,0xC5,0xC6,	0xC7,0xC8,0xC9,0xCA,0x1B,0xCC,0xCD,0xCE,
	0xCF,0xD0,0xD1,0xD2,0xD3,0xD4,0xD5,0x1C,	0xD7,0xD8,0xD9,0xDA,0xDB,0xDC,0xDD,0xDE,
	0xDF,0xE0,0x1E,0xE2,0xE3,0xE4,0xE5,0xE6,	0xE7,0xE8,0xE9,0xE3,0x1D,0xEC,0x1D,0xEA,
	0x1E,0xED,0x1F,0xF2,0xF3,0xF4,0xF5,0xF6,	0xF7,0xF8,0xF9,0xFA,0xFB,0x20,0xFD,0xFE,
	0xFF,0xFF,0x42,0x08,0x0C,0x28,0xB0,0xA0,	0x41,0x80,0xFD,0x0E,0x26,0x2C,0x88,0xB0,
	0x21,0x88,0x82,0x23,0x22,0x4A,0x9C,0x48,	0xB1,0xA2,0xC5,0x8B,0x18,0x33,0x6A,0x2C,
	0xC1,0xB1,0xA3,0xC7,0x8F,0x20,0x43,0x8A,	0x1C,0x49,0xB2,0x24,0x8A,0x93,0x27,0x52,
	0x9E,0x38,0xC9,0xB2,0xA5,0x4B,0x95,0x30,	0x5D,0xBE,0x84,0x49,0xB3,0x25,0xCD,0x9B,
	0x2A,0x63,0xE8,0xDC,0xC9,0xB3,0xA7,0xCF,	0x9F,0x40,0x83,0x0A,0x1D,0x2A,0xA3,0xA8,
	0xD1,0xA3,0x48,0x93,0x2A,0x5D,0xCA,0xB4,	0xA9,0xD3,0x19,0x50,0xA3,0x4A,0x9D,0x4A,
	0xB5,0xAA,0xD5,0xAB,0x58,0xB3,0xD2,0xD8,	0xCA,0xB5,0xAB,0xD7,0xAF,0x60,0xC3,0x8A,
	0x1D,0x4B,0xB6,0x86,0xD9,0xB3,0x68,0xD3,	0xAA,0x5D,0xCB,0xB6,0xAD,0xDB,0xB7,0x36,
	0xFF,0xE2,0xCA,0x9D,0x4B,0xB7,0xAE,0xDD,	0xBB,0x78,0xF3,0xEA,0xBD,0xC1,0xB7,0xAF,
	0xDF,0xBF,0x80,0x03,0x0B,0x1E,0x4C,0xB8,	0x30,0x8E,0xC3,0x88,0x13,0x2B,0x5E,0xCC,
	0xB8,0xB1,0xE3,0xC7,0x90,0x73,0x48,0x9E,	0x4C,0xB9,0xB2,0xE5,0xCB,0x98,0x33,0x6B,
	0xDE,0xAC,0xA3,0xB3,0xE7,0xCF,0xA0,0x43,	0x8B,0x1E,0x4D,0xBA,0xB4,0xE9,0x1D,0xA8,
	0x53,0xAB,0x5E,0xCD,0xBA,0xB5,0xEB,0xD7,	0xB0,0x63,0xF3,0x98,0x4D,0xBB,0xB6,0xED,
	0xDB,0xB8,0x73,0xEB,0xDE,0xCD,0xBB,0x87,	0xEF,0xDF,0xC0,0x83,0x0B,0x1F,0x4E,0xBC,
	0xB8,0xF1,0xE3,0x3E,0x92,0x2B,0x5F,0xCE,	0xBC,0xB9,0xF3,0xE7,0xD0,0xA3,0x4B,0xFF,
	0x41,0xBD,0xBA,0xF5,0xEB,0xD8,0xB3,0x6B,	0xDF,0xCE,0xBD,0x3B,0x90,0xEF,0xE0,0xC3,
	0x8B,0x1F,0x4F,0xBE,0xBC,0xF9,0xF3,0xE8,	0x31,0xA8,0x5F,0xCF,0xBE,0xBD,0xFB,0xF7,
	0xF0,0xE3,0xCB,0x9F,0x1F,0xA0,0xBE,0xFD,	0xFB,0xF8,0xF3,0xEB,0xDF,0xCF,0xBF,0xBF,
	0x7F,0x01,0x00,0x06,0x28,0xC0,0x00,0x04,	0x16,0x68,0xE0,0x81,0x08,0x06,0x68,0xA0,
	0x80,0x0C,0x32,0x88,0xE0,0x00,0x0D,0x0A,	0xF8,0xE0,0x84,0x14,0x56,0x68,0xE1,0x85,
	0x14,0x12,0xA0,0xE1,0x86,0x1C,0x76,0xE8,	0x61,0x01,0x20,0x16,0xE0,0xE1,0x88,0x24,
	0x96,0x68,0x22,0x01,0x21,0xA6,0xA8,0xE2,	0x8A,0x2C,0xB6,0xE8,0xE2,0x8B,0x30,0x86,
	0x78,0xC0,0x8C,0x34,0xD6,0x68,0xE3,0x8D,	0x38,0xE6,0xA8,0xE3,0x8E,0x3C,0x22,0xE0,
	0xE3,0x8F,0x40,0x06,0x29,0xE4,0x90,0x44,	0x16,0x69,0xE4,0x91,0x09,0x24,0xA9,0xE4,
	0xFF,0x92,0x4C,0x36,0xE9,0xE4,0x93,0x50,	0x46,0x29,0xA5,0x02,0x54,0x56,0x69,0xE5,
	0x95,0x58,0x66,0xA9,0xE5,0x96,0x5C,0x76,	0xC9,0xC0,0x97,0x60,0x86,0x29,0xE6,0x98,
	0x64,0x96,0x69,0x26,0x98,0x0B,0xA4,0xB9,	0xC0,0x99,0x0C,0xA8,0xD9,0xC0,0x9B,0x70,
	0xC6,0x29,0xE7,0x9C,0x74,0xD6,0x69,0xE7,	0x9D,0x78,0x3A,0xA0,0xE7,0x9E,0x7C,0xF6,
	0xE9,0xE7,0x9F,0x80,0x06,0x2A,0xE8,0xA0,	0x0F,0x14,0x6A,0xE8,0xA1,0x88,0x26,0xAA,
	0xE8,0xA2,0x8C,0x36,0xEA,0x28,0x04,0x90,	0x46,0x2A,0xE9,0xA4,0x94,0x56,0x6A,0xE9,
	0xA5,0x98,0x66,0x2A,0xC1,0xA6,0x11,0x74,	0x1A,0xC1,0xA6,0xA0,0x86,0x2A,0xAA,0xA7,
	0xA4,0x8A,0x3A,0x2A,0xA9,0xA8,0x86,0x8A,	0xEA,0xAA,0x9E,0x2A,0xE3,0xEA,0xAB,0xB0,
	0xC6,0xAA,0x81,0x08,0xB4,0xD6,0x6A,0xEB,	0xAD,0xB8,0xE6,0xAA,0xEB,0xAE,0xBC,0xF6,
	0x4A,0xC2,0xAF,0xC0,0x06,0x2B,0xEC,0xB0,	0xC4,0x16,0x6B,0xEC,0xB1,0xC8,0x96,0xA4,
	0xEC,0xB2,0xCC,0x36,0x5B,0x82,0x09,0xD0,	0x46,0x2B,0xED,0xB4,0xD4,0x56,0x6B,0xED,
	0xB5,0xD8,0x66,0x2B,0xD3,0xB6,0xDC,0x76,	0xEB,0xED,0xB7,0xE0,0xB2,0x94,0xC2,0xB8,
	0xE4,0x96,0x6B,0xEE,0xB9,0xE8,0xA6,0xAB,	0xEE,0xBA,0xEC,0xB6,0xEB,0xEE,0xBB,0xF0,
	0xB6,0xAB,0xC2,0xBC,0xF4,0xD6,0x6B,0xEF,	0xBD,0xF8,0xE6,0xAB,0xEF,0xBE,0xFC,0xAE,
	0xE0,0xEF,0xBF,0x00,0x07,0x2C,0xF0,0xC0,	0x04,0x17,0x6C,0xF0,0xC1,0x2C,0x24,0xAC,
	0xF0,0xC2,0x0C,0x37,0xEC,0xF0,0xC3,0x10,	0x47,0x2C,0x71,0x0B,0x14,0x57,0x6C,0xF1,
	0x55,0xC5,0x18,0x67,0xAC,0xF1,0xC6,0x1C,	0x77,0xEC,0xC2,0xC7,0x20,0x87,0x2C,0xF2,
	0xC8,0x24,0x97,0x6C,0xF2,0xC9,0x28,0xBF,	0xA0,0xF2,0xCA,0x2C,0xB7,0xEC,0xF2,0xCB,
	0x30,0xC7,0x2C,0xF3,0xCC,0x30,0xD4,0x6C,	0xF3,0xCD,0x38,0xE7,0xAC,0xF3,0xCE,0x3C,
	0xF7,0xEC,0xF3,0xCF,0x40,0x07,0x2D,0xF4,	0xCF,0x06,0x14,0x6D,0xF4,0xD1,0x48,0x27,
	0xAD,0xF4,0xD2,0x4C,0x37,0xED,0x34,0x00,	0x50,0x47,0x2D,0xF5,0xD4,0x54,0x57,0x6D,
	0xF5,0xD5,0x58,0x67,0x1D,0x08,0x00,0x3B
};
#endif //_MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/bmp/skin_caption.gif.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */

#include "common.h"

#ifdef _MGINCORE_RES

//data of "skin_caption.gif"

const unsigned char _mgir_gif_skin_caption_data[]={
	0x47,0x49,0x46,0x38,0x39,0x61,0x42,0x00,	0x40,0x00,0xE6,0x00,0x00,0xB9,0xB9,0xB9,
	0xAA,0xAA,0xAA,0x7E,0x7E,0x7E,0x7D,0x7D,	0x7D,0x7B,0x7B,0x7B,0x7A,0x7A,0x7A,0x79,
	0x79,0x79,0x78,0x78,0x78,0x76,0x76,0x76,	0x74,0x74,0x74,0x73,0x73,0x73,0x71,0x71,
	0x71,0x70,0x70,0x70,0x6E,0x6E,0x6E,0x6C,	0x6C,0x6C,0x6A,0x6A,0x6A,0x67,0x67,0x67,
	0x66,0x66,0x66,0x65,0x65,0x65,0x62,0x62,	0x62,0x61,0x61,0x61,0x5F,0x5F,0x5F,0x5E,
	0x5E,0x5E,0x5D,0x5D,0x5D,0x5C,0x5C,0x5C,	0x5B,0x5B,0x5B,0x59,0x59,0x59,0x56,0x56,
	0x56,0x55,0x55,0x55,0x52,0x52,0x52,0x51,	0x51,0x51,0x4F,0x4F,0x4F,0x4D,0x4D,0x4D,
	0x4C,0x4C,0x4C,0x4B,0x4B,0x4B,0x4A,0x4A,	0x4A,0x49,0x49,0x49,0x47,0x47,0x47,0x46,
	0x46,0x46,0x45,0x45,0x45,0x44,0x44,0x44,	0x42,0x42,0x42,0x40,0x40,0x40,0x3E,0x3E,
	0x3E,0x3D,0x3D,0x3D,0x3C,0x3C,0x3C,0x3B,	0x3B,0x3B,0x3A,0x3A,0x3A,0x39,0x39,0x39,
	0x36,0x36,0x36,0x24,0x24,0x24,0x22,0x22,	0x22,0x20,0x20,0x20,0x1E,0x1E,0x1E,0x1C,
	0x1C,0x1C,0x1A,0x1A,0x1A,0x19,0x19,0x19,	0x17,0x17,0x17,0x15,0x15,0x15,0x14,0x14,
	0x14,0x12,0x12,0x12,0x11,0x11,0x11,0x10,	0x10,0x10,0x0F,0x0F,0x0F,0x0E,0x0E,0x0E,
	0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,	0x00,0x00,0x00,0x00,0x00,0x21,0xF9,0x04,
	0x01,0x00,0x00,0x41,0x00,0x2C,0x00,0x00,	0x00,0x00,0x42,0x00,0x40,0x00,0x00,0x07,
	0xFF,0x80,0x13,0x82,0x83,0x13,0x14,0x86,	0x87,0x88,0x89,0x8A,0x83,0x88,0x84,0x8E,
	0x8E,0x8A,0x14,0x8F,0x84,0x91,0x95,0x96,	0x97,0x98,0x99,0x96,0x15,0x9C,0x9D,0x9E,
	0x9F,0xA0,0x16,0xA2,0x16,0xA0,0xA5,0xA6,	0xA7,0xA8,0x15,0x17,0xAB,0xAC,0xAD,0xAE,
	0xAF,0xB0,0xB1,0xB2,0xB3,0xB4,0x19,0xB6,	0xB7,0xB8,0xB9,0xBA,0xBB,0xBC,0xBD,0xBE,
	0xBF,0x1A,0xC1,0xC2,0xC3,0xC4,0xC5,0xC6,	0xC7,0xC8,0xC9,0xCA,0x1B,0xCC,0xCD,0xCE,
	0xCF,0xD0,0xD1,0xD2,0xD3,0xD4,0xD5,0x1C,	0xD7,0xD8,0xD9,0xDA,0xDB,0xDC,0xDD,0xDE,
	0xDF,0xE0,0x1E,0xE2,0xE3,0xE4,0xE5,0xE6,	0xE7,0xE8,0xE9,0xE3,0x1D,0xEC,0x1D,0xEA,
	0x1E,0xED,0x1F,0xF2,0xF3,0xF4,0xF5,0xF6,	0xF7,0xF8,0xF9,0xFA,0xFB,0x20,0xFD,0xFE,
	0xFF,0xFF,0x42,0x08,0x0C,0x28,0xB0,0xA0,	0x41,0x80,0xFD,0x0E,0x26,0x2C,0x88,0xB0,
	0x21,0x88,0x82,0x23,0x22,0x4A,0x9C,0x48,	0xB1,0xA2,0xC5,0x8B,0x18,0x33,0x6A,0x2C,
	0xC1,0xB1,0xA3,0xC7,0x8F,0x20,0x43,0x8A,	0x1C,0x49,0xB2,0x24,0x8A,0x93,0x27,0x52,
	0x9E,0x38,0xC9,0xB2,0xA5,0x4B,0x95,0x30,	0x5D,0xBE,0x84,0x49,0xB3,0x25,0xCD,0x9B,
	0x2A,0x63,0xE8,0xDC,0xC9,0xB3,0xA7,0xCF,	0x9F,0x40,0x83,0x0A,0x1D,0x2A,0xA3,0xA8,
	0xD1,0xA3,0x48,0x93,0x2A,0x5D,0xCA,0xB4,	0xA9,0xD3,0x19,0x50,0xA3,0x4A,0x9D,0x4A,
	0xB5,0xAA,0xD5,0xAB,0x58,0xB3,0xD2,0xD8,	0xCA,0xB5,0xAB,0xD7,0xAF,0x60,0xC3,0x8A,
	0x1D,0x4B,0xB6,0x86,0xD9,0xB3,0x68,0xD3,	0xAA,0x5D,0xCB,0xB6,0xAD,0xDB,0xB7,0x36,
	0xFF,0xE2,0xCA,0x9D,0x4B,0xB7,0xAE,0xDD,	0xBB,0x78,0xF3,0xEA,0xBD,0xC1,0xB7,0xAF,
	0xDF,0xBF,0x80,0x03,0x0B,0x1E,0x4C,0xB8,	0x30,0x8E,0xC3,0x88,0x13,0x2B,0x5E,0xCC,
	0xB8,0xB1,0xE3,0xC7,0x90,0x73,0x48,0x9E,	0x4C,0xB9,0xB2,0xE5,0xCB,0x98,0x33,0x6B,
	0xDE,0xAC,0xA3,0xB3,0xE7,0xCF,0xA0,0x43,	0x8B,0x1E,0x4D,0xBA,0xB4,0xE9,0x1D,0xA8,
	0x53,0xAB,0x5E,0xCD,0xBA,0xB5,0xEB,0xD7,	0xB0,0x63,0xF3,0x98,0x4D,0xBB,0xB6,0xED,
	0xDB,0xB8,0x73,0xEB,0xDE,0xCD,0xBB,0x87,	0xEF,0xDF,0xC0,0x83,0x0B,0x1F,0x4E,0xBC,
	0xB8,0xF1,0xE3,0x3E,0x92,0x2B,0x5F,0xCE,	0xBC,0xB9,0xF3,0xE7,0xD0,0xA3,0x4B,0xFF,
	0x41,0xBD,0xBA,0xF5,0xEB,0xD8,0xB3,0x6B,	0xDF,0xCE,0xBD,0x3B,0x90,0xEF,0xE0,0xC3,
	0x8B,0x1F,0x4F,0xBE,0xBC,0xF9,0xF3,0xE8,	0x31,0xA8,0x5F,0xCF,0xBE,0xBD,0xFB,0xF7,
	0xF0,0xE3,0xCB,0x9F,0x1F,0xA0,0xBE,0xFD,	0xFB,0xF8,0xF3,0xEB,0xDF,0xCF,0xBF,0xBF,
	0x7F,0x01,0x00,0x06,0x28,0xC0,0x00,0x04,	0x16,0x68,0xE0,0x81,0x08,0x06,0x68,0xA0,
	0x80,0x0C,0x32,0x88,0xE0,0x00,0x0D,0x0A,	0xF8,0xE0,0x84,0x14,0x56,0x68,0xE1,0x85,
	0x14,0x12,0xA0,0xE1,0x86,0x1C,0x76,0xE8,	0x61,0x01,0x20,0x16,0xE0,0xE1,0x88,0x24,
	0x96,0x68,0x22,0x01,0x21,0xA6,0xA8,0xE2,	0x8A,0x2C,0xB6,0xE8,0xE2,0x8B,0x30,0x86,
	0x78,0xC0,0x8C,0x34,0xD6,0x68,0xE3,0x8D,	0x38,0xE6,0xA8,0xE3,0x8E,0x3C,0x22,0xE0,
	0xE3,0x8F,0x40,0x06,0x29,0xE4,0x90,0x44,	0x16,0x69,0xE4,0x91,0x09,0x24,0xA9,0xE4,
	0xFF,0x92,0x4C,0x36,0xE9,0xE4,0x93,0x50,	0x46,0x29,0xA5,0x02,0x54,0x56,0x69,0xE5,
	0x95,0x58,0x66,0xA9,0xE5,0x96,0x5C,0x76,	0xC9,0xC0,0x97,0x60,0x86,0x29,0xE6,0x98,
	0x64,0x96,0x69,0x26,0x98,0x0B,0xA4,0xB9,	0xC0,0x99,0x0C,0xA8,0xD9,0xC0,0x9B,0x70,
	0xC6,0x29,0xE7,0x9C,0x74,0xD6,0x69,0xE7,	0x9D,0x78,0x3A,0xA0,0xE7,0x9E,0x7C,0xF6,
	0xE9,0xE7,0x9F,0x80,0x06,0x2A,0xE8,0xA0,	0x0F,0x14,0x6A,0xE8,0xA1,0x88,0x26,0xAA,
	0xE8,0xA2,0x8C,0x36,0xEA,0x28,0x04,0x90,	0x46,0x2A,0xE9,0xA4,0x94,0x56,0x6A,0xE9,
	0xA5,0x98,0x66,0x2A,0xC1,0xA6,0x11,0x74,	0x1A,0xC1,0xA6,0xA0,0x86,0x2A,0xAA,0xA7,
	0xA4,0x8A,0x3A,0x2A,0xA9,0xA8,0x86,0x8A,	0xEA,0xAA,0x9E,0x2A,0xE3,0xEA,0xAB,0xB0,
	0xC6,0xAA,0x81,0x08,0xB4,0xD6,0x6A,0xEB,	0xAD,0xB8,0xE6,0xAA,0xEB,0xAE,0xBC,0xF6,
	0x4A,0xC2,0xAF,0xC0,0x06,0x2B,0xEC,0xB0,	0xC4,0x16,0x6B,0xEC,0xB1,0xC8,0x96,0xA4,
	0xEC,0xB2,0xCC,0x36,0x5B,0x82,0x09,0xD0,	0x46,0x2B,0xED,0xB4,0xD4,0x56,0x6B,0xED,
	0xB5,0xD8,0x66,0x2B,0xD3,0xB6,0xDC,0x76,	0xEB,0xED,0xB7,0xE0,0xB2,0x94,0xC2,0xB8,
	0xE4,0x96,0x6B,0xEE,0xB9,0xE8,0xA6,0xAB,	0xEE,0xBA,0xEC,0xB6,0xEB,0xEE,0xBB,0xF0,
	0xB6,0xAB,0xC2,0xBC,0xF4,0xD6,0x6B,0xEF,	0xBD,0xF8,0xE6,0xAB,0xEF,0xBE,0xFC,0xAE,
	0xE0,0xEF,0xBF,0x00,0x07,0x2C,0xF0,0xC0,	0x04,0x17,0x6C,0xF0,0xC1,0x2C,0x24,0xAC,
	0xF0,0xC2,0x0C,0x37,0xEC,0xF0,0xC3,0x10,	0x47,0x2C,0x71,0x0B,0x14,0x57,0x6C,0xF1,
	0x55,0xC5,0x18,0x67,0xAC,0xF1,0xC6,0x1C,	0x77,0xEC,0xC2,0xC7,0x20,0x87,0x2C,0xF2,
	0xC8,0x24,0x97,0x6C,0xF2,0xC9,0x28,0xBF,	0xA0,0xF2,0xCA,0x2C,0xB7,0xEC,0xF2,0xCB,
	0x30,0xC7,0x2C,0xF3,0xCC,0x30,0xD4,0x6C,	0xF3,0xCD,0x38,0xE7,0xAC,0xF3,0xCE,0x3C,
	0xF7,0xEC,0xF3,0xCF,0x40,0x07,0x2D,0xF4,	0xCF,0x06,0x14,0x6D,0xF4,0xD1,0x48,0x27,
	0xAD,0xF4,0xD2,0x4C,0x37,0xED,0x34,0x00,	0x50,0x47,0x2D,0xF5,0xD4,0x54,0x57,0x6D,
	0xF5,0xD5,0x58,0x67,0x1D,0x08,0x00,0x3B
};
#endif //_MGINCORE_RES
